@@ -339,8 +339,8 @@ _dataset_version_pretty_names = {  # from qa4sm\validator\fixtures\versions.json
     "ERA5_LAND_TEST": "ERA5-Land test",
     "CGLS_CSAR_SSM1km_V1_1": "v1_1",
     "CGLS_SCATSAR_SWI1km_V1_0": "v1_0",
-    "Level3_ASC": "Level3 Ascending",
-    "Level3_DESC": "Level3 Descending",
+    "SMOSL3_v339_ASC": "version 339 Ascending",
+    "SMOSL3_v339_DESC": "version 339 Descending",
 }
 
 # fallback for dataset val_dc_variable in case they are not in the metadata
@@ -374,8 +374,8 @@ _dataset_variable_names = {  # from qa4sm\validator\fixtures\versions.json
     "ERA5_LAND_TEST": "svwl1",
     "CGLS_CSAR_SSM1km_V1_1": "soil moisture",
     "CGLS_SCATSAR_SWI1km_V1_0": "SWI",
-    "Level3_ASC": "soil moisture",
-    "Level3_DESC": "soil moisture"
+    "SMOSL3_v339_ASC": "soil moisture",
+    "SMOSL3_v339_DESC": "soil moisture"
 }
 
 
@@ -425,7 +425,7 @@ def get_resolution_info(dataset, raise_error=False):
         'SMOS_IC': 'km',
         'CGLS_CSAR_SSM1km': 'km',
         'CGLS_SCATSAR_SWI1km': 'km',
-        'SMOS_L3': 'deg',
+        'SMOS_L3': 'km',
     }
 
     try:
@@ -552,7 +552,7 @@ metadata = {
     "instrument_depthfrom": ("upper depth", None, "continuous", "[m]"),
     "instrument_depthto": ("lower depth", None, "continuous", "[m]"),
     # --- generated during the image initialization:
-    "soil_type": ("soil texture", None, "discrete", None),
+    "soil_type": ("soil granulometry", None, "discrete", None),
     "instrument_depth": ("instrument depth", None, "continuous", "[m]"),
 }
 
